Python Module Index — pySciSci 0.6 documentation

# Python Module Index

a | b | d | p | u

| a |
| `authormetrics` | Set of functions for the bibliometric analysis of authors
| b |
| `bibnetwork` | The main Network class
| d |
| `datasource` | Set of classes to work with different bibliometric data sources
| p |
| `publicationmetrics` | Set of functions for the bibliometric analysis of publications
| `pyscisci` |
| `pyscisci.database` |
| `pyscisci.datasource.APS` |
| `pyscisci.datasource.CustomDB` |
| `pyscisci.datasource.DBLP` |
| `pyscisci.datasource.MAG` |
| `pyscisci.datasource.OpenAlex` |
| `pyscisci.datasource.PubMed` |
| `pyscisci.datasource.WOS` |
| `pyscisci.methods.author` |
| `pyscisci.methods.publication` |
| `pyscisci.network` |
| `pyscisci.utils` |
| u |
| `utils` | utils for basic functions